shadow-git-inject.core


boolean?clj

(boolean? x)

Return true if x is a Boolean

Return true if x is a Boolean
sourceraw docstring

default-configclj

The default configuration values.

The default configuration values.
sourceraw docstring

describeclj

(describe {:keys [git] :as config})

Uses git-describe to parse the status of the repository. Using the configured git and describe-pattern to parse the output. Returns a map {:tag, :ahead, :ahead?, :ref, :ref-short, :dirty?} if the pattern matches, otherwise returns the empty map.

Uses git-describe to parse the status of the repository.
Using the configured `git` and `describe-pattern` to parse the output.
Returns a map `{:tag, :ahead, :ahead?, :ref, :ref-short, :dirty?}`
if the pattern matches, otherwise returns the empty map.
sourceraw docstring

ensure-patternclj

(ensure-pattern x label)

Given a string, compiles it to a java.util.regex.Pattern.

Given a string, compiles it to a java.util.regex.Pattern.
sourceraw docstring

git-status-to-versionclj

(git-status-to-version {:keys [version-pattern ignore-dirty?] :as config})
source

hookclj

(hook {:keys [git-inject] :as build-state} & args)
source

injectclj

(inject state config)
source

latest-version-tagclj

(latest-version-tag {:keys [version-pattern] :as config})
source

let-groupscljmacro

(let-groups [bindings m] & body)

Let for binding groups out of a j.u.r.Pattern j.u.r.Matcher.

Let for binding groups out of a j.u.r.Pattern j.u.r.Matcher.
sourceraw docstring

parse-describeclj

(parse-describe {:keys [describe-pattern] :as config} out)

Used to parse the output of git-describe, using the configured describe-pattern. Returns a map {:tag, :ahead, :ahead?, :ref, :ref-short, :dirty?} if the pattern matches, otherwise returns the empty map.

Used to parse the output of git-describe, using the configured `describe-pattern`.
Returns a map `{:tag, :ahead, :ahead?, :ref, :ref-short, :dirty?}`
if the pattern matches, otherwise returns the empty map.
sourceraw docstring

resolve-refclj

(resolve-ref {:keys [git] :as config} ref)

Fetches the git ref of ref, being a tag or ref name.

Fetches the git ref of ref, being a tag or ref name.
sourceraw docstring

tagsclj

(tags {:keys [git] :as config})

Returns all tags merged into HEAD, ordered by creation date (most recent first).

Uses --sort=-creatordate (not -committerdate) because committerdate is empty for annotated tag objects, which sorts every annotated tag below every lightweight tag regardless of when it was made. creatordate is documented as the right field for sorting a mix of annotated and lightweight tags.

Returns all tags merged into HEAD, ordered by creation date (most recent first).

Uses --sort=-creatordate (not -committerdate) because committerdate is empty
for annotated tag objects, which sorts every annotated tag below every
lightweight tag regardless of when it was made. creatordate is documented as
the right field for sorting a mix of annotated and lightweight tags.
sourceraw docstring

x->fclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries